@@ -17,72 +17,24 @@ import uuid
 
 from oslo_db.sqlalchemy import models
 from oslo_utils import timeutils
-import six
 import sqlalchemy
 from sqlalchemy.ext import declarative
 from sqlalchemy.orm import backref
 from sqlalchemy.orm import relationship
-from sqlalchemy.orm import session as orm_session
 
 from heat.db.sqlalchemy import types
 
 BASE = declarative.declarative_base()
 
 
-def get_session():
-    from heat.db.sqlalchemy import api as db_api
-    return db_api.get_session()
-
-
 class HeatBase(models.ModelBase, models.TimestampMixin):
     """Base class for Heat Models."""
     __table_args__ = {'mysql_engine': 'InnoDB'}
 
-    def expire(self, session=None, attrs=None):
-        """Expire this object ()."""
-        if not session:
-            session = orm_session.Session.object_session(self)
-            if not session:
-                session = get_session()
-        session.expire(self, attrs)
-
-    def refresh(self, session=None, attrs=None):
-        """Refresh this object."""
-        if not session:
-            session = orm_session.Session.object_session(self)
-            if not session:
-                session = get_session()
-        session.refresh(self, attrs)
-
-    def delete(self, session=None):
-        """Delete this object."""
-        if not session:
-            session = orm_session.Session.object_session(self)
-            if not session:
-                session = get_session()
-        session.begin(subtransactions=True)
-        session.delete(self)
-        session.commit()
-
-    def update_and_save(self, values, session=None):
-        if not session:
-            session = orm_session.Session.object_session(self)
-            if not session:
-                session = get_session()
-        session.begin(subtransactions=True)
-        for k, v in six.iteritems(values):
-            setattr(self, k, v)
-        session.commit()
-
 
 class SoftDelete(object):
     deleted_at = sqlalchemy.Column(sqlalchemy.DateTime)
 
-    def soft_delete(self, session=None):
-        """Mark this object as deleted."""
-        self.update_and_save({'deleted_at': timeutils.utcnow()},
-                             session=session)
-
 
 class StateAware(object):
     action = sqlalchemy.Column('action', sqlalchemy.String(255))
@@ -96,10 +48,22 @@ class RawTemplate(BASE, HeatBase):
     __tablename__ = 'raw_template'
     id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
     template = sqlalchemy.Column(types.Json)
+    # legacy column
     files = sqlalchemy.Column(types.Json)
+    # modern column, reference to raw_template_files
+    files_id = sqlalchemy.Column(
+        sqlalchemy.Integer(),
+        sqlalchemy.ForeignKey('raw_template_files.id'))
     environment = sqlalchemy.Column('environment', types.Json)
 
 
+class RawTemplateFiles(BASE, HeatBase):
+    """Where template files json dicts are stored."""
+    __tablename__ = 'raw_template_files'
+    id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
+    files = sqlalchemy.Column(types.Json)
+
+
 class StackTag(BASE, HeatBase):
     """Key/value store of arbitrary stack tags."""
 
@@ -219,6 +183,16 @@ class UserCreds(BASE, HeatBase):
                          cascade_backrefs=False)
 
 
+class ResourcePropertiesData(BASE, HeatBase):
+    """Represents resource properties data, current or older"""
+
+    __tablename__ = 'resource_properties_data'
+
+    id = sqlalchemy.Column(sqlalchemy.Integer, primary_key=True)
+    data = sqlalchemy.Column('data', types.Json)
+    encrypted = sqlalchemy.Column('encrypted', sqlalchemy.Boolean)
+
+
 class Event(BASE, HeatBase):
     """Represents an event generated by the heat engine."""
 
@@ -240,6 +214,11 @@ class Event(BASE, HeatBase):
     _resource_status_reason = sqlalchemy.Column(
         'resource_status_reason', sqlalchemy.String(255))
     resource_type = sqlalchemy.Column(sqlalchemy.String(255))
+    rsrc_prop_data_id = sqlalchemy.Column(sqlalchemy.Integer,
+                                          sqlalchemy.ForeignKey(
+                                              'resource_properties_data.id'))
+    rsrc_prop_data = relationship(ResourcePropertiesData,
+                                  backref=backref('event'))
     resource_properties = sqlalchemy.Column(sqlalchemy.PickleType)
 
     @property
@@ -264,10 +243,11 @@ class ResourceData(BASE, HeatBase):
     value = sqlalchemy.Column('value', sqlalchemy.Text)
     redact = sqlalchemy.Column('redact', sqlalchemy.Boolean)
     decrypt_method = sqlalchemy.Column(sqlalchemy.String(64))
-    resource_id = sqlalchemy.Column('resource_id',
-                                    sqlalchemy.Integer,
-                                    sqlalchemy.ForeignKey('resource.id'),
-                                    nullable=False)
+    resource_id = sqlalchemy.Column(
+        'resource_id', sqlalchemy.Integer,
+        sqlalchemy.ForeignKey(column='resource.id', name='fk_resource_id',
+                              ondelete='CASCADE'),
+        nullable=False)
 
 
 class Resource(BASE, HeatBase, StateAware):
@@ -280,7 +260,8 @@ class Resource(BASE, HeatBase, StateAware):
                              default=lambda: str(uuid.uuid4()),
                              unique=True)
     name = sqlalchemy.Column('name', sqlalchemy.String(255))
-    nova_instance = sqlalchemy.Column('nova_instance', sqlalchemy.String(255))
+    physical_resource_id = sqlalchemy.Column('nova_instance',
+                                             sqlalchemy.String(255))
     # odd name as "metadata" is reserved
     rsrc_metadata = sqlalchemy.Column('rsrc_metadata', types.Json)
 
@@ -290,8 +271,14 @@ class Resource(BASE, HeatBase, StateAware):
     stack = relationship(Stack, backref=backref('resources'))
     root_stack_id = sqlalchemy.Column(sqlalchemy.String(36), index=True)
     data = relationship(ResourceData,
-                        cascade="all,delete",
+                        cascade="all",
+                        passive_deletes=True,
                         backref=backref('resource'))
+    rsrc_prop_data_id = sqlalchemy.Column(sqlalchemy.Integer,
+                                          sqlalchemy.ForeignKey(
+                                              'resource_properties_data.id'))
+    rsrc_prop_data = relationship(ResourcePropertiesData,
+                                  backref=backref('resource'))
 
     # Override timestamp column to store the correct value: it should be the
     # time the create/update call was issued, not the time the DB entry is
