@@ -11,19 +11,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
-from sqlalchemy.util.compat import pickle
-
-import oslo_db.exception
-from oslo_log import log as logging
-
 from heat.common import identifier
 from heat.objects import event as event_object
-
-LOG = logging.getLogger(__name__)
-
-MAX_EVENT_RESOURCE_PROPERTIES_SIZE = (1 << 16) - 1
+from heat.objects import resource_properties_data as rpd_objects
 
 
 class Event(object):
@@ -45,10 +35,17 @@ class Event(object):
         self.physical_resource_id = physical_resource_id
         self.resource_name = resource_name
         self.resource_type = resource_type
-        try:
-            self.resource_properties = dict(resource_properties)
-        except ValueError as ex:
-            self.resource_properties = {'Error': six.text_type(ex)}
+        self.rsrc_prop_data = None
+        if isinstance(resource_properties,
+                      rpd_objects.ResourcePropertiesData):
+            self.rsrc_prop_data = resource_properties
+            self.resource_properties = self.rsrc_prop_data.data
+        elif resource_properties is None:
+            self.resource_properties = {}
+        else:
+            raise AssertionError(
+                'resource_properties is unexpected type %s' %
+                type(resource_properties).__name__)
         self.uuid = uuid
         self.timestamp = timestamp
         self.id = id
@@ -63,7 +60,6 @@ class Event(object):
             'resource_status': self.status,
             'resource_status_reason': self.reason,
             'resource_type': self.resource_type,
-            'resource_properties': self.resource_properties,
         }
 
         if self.uuid is not None:
@@ -72,39 +68,10 @@ class Event(object):
         if self.timestamp is not None:
             ev['created_at'] = self.timestamp
 
-        # Workaround: we don't want to attempt to store the
-        # event.resource_properties column if the data is too large
-        # (greater than permitted by BLOB). Otherwise, we end up with
-        # an unsightly log message.
-        rp_size = len(pickle.dumps(ev['resource_properties'],
-                                   pickle.HIGHEST_PROTOCOL))
-        if rp_size > MAX_EVENT_RESOURCE_PROPERTIES_SIZE:
-            LOG.debug('event\'s resource_properties too large to store at '
-                      '%d bytes', rp_size)
-            # Try truncating the largest value and see if that gets us under
-            # the db column's size constraint.
-            max_key, max_val = max(ev['resource_properties'].items(),
-                                   key=lambda i: len(repr(i[1])))
-            err = 'Resource properties are too large to store fully'
-            ev['resource_properties'].update({'Error': err})
-            ev['resource_properties'][max_key] = '<Deleted, too large>'
-            rp_size = len(pickle.dumps(ev['resource_properties'],
-                                       pickle.HIGHEST_PROTOCOL))
-            if rp_size > MAX_EVENT_RESOURCE_PROPERTIES_SIZE:
-                LOG.debug('event\'s resource_properties STILL too large '
-                          'after truncating largest key at %d bytes', rp_size)
-                err = 'Resource properties are too large to attempt to store'
-                ev['resource_properties'] = {'Error': err}
+        if self.rsrc_prop_data:
+            ev['rsrc_prop_data_id'] = self.rsrc_prop_data.id
 
-        # We should have worked around the issue, but let's be extra
-        # careful.
-        try:
-            new_ev = event_object.Event.create(self.context, ev)
-        except oslo_db.exception.DBError:
-            # Give up and drop all properties..
-            err = 'Resource properties are too large to store'
-            ev['resource_properties'] = {'Error': err}
-            new_ev = event_object.Event.create(self.context, ev)
+        new_ev = event_object.Event.create(self.context, ev)
 
         self.id = new_ev.id
         self.timestamp = new_ev.created_at
