@@ -123,35 +123,39 @@ class KeystoneRoleAssignmentMixin(object):
                     user=user_id
                 )
 
-    def _remove_role_assignments_from_group(self, group_id, role_assignments):
+    def _remove_role_assignments_from_group(self, group_id, role_assignments,
+                                            current_assignments):
         for role_assignment in self._normalize_to_id(role_assignments):
-            if role_assignment.get(self.PROJECT) is not None:
-                self.client().roles.revoke(
-                    role=role_assignment.get(self.ROLE),
-                    project=role_assignment.get(self.PROJECT),
-                    group=group_id
-                )
-            elif role_assignment.get(self.DOMAIN) is not None:
-                self.client().roles.revoke(
-                    role=role_assignment.get(self.ROLE),
-                    domain=role_assignment.get(self.DOMAIN),
-                    group=group_id
-                )
+            if role_assignment in current_assignments:
+                if role_assignment.get(self.PROJECT) is not None:
+                    self.client().roles.revoke(
+                        role=role_assignment.get(self.ROLE),
+                        project=role_assignment.get(self.PROJECT),
+                        group=group_id
+                    )
+                elif role_assignment.get(self.DOMAIN) is not None:
+                    self.client().roles.revoke(
+                        role=role_assignment.get(self.ROLE),
+                        domain=role_assignment.get(self.DOMAIN),
+                        group=group_id
+                    )
 
-    def _remove_role_assignments_from_user(self, user_id, role_assignments):
+    def _remove_role_assignments_from_user(self, user_id, role_assignments,
+                                           current_assignments):
         for role_assignment in self._normalize_to_id(role_assignments):
-            if role_assignment.get(self.PROJECT) is not None:
-                self.client().roles.revoke(
-                    role=role_assignment.get(self.ROLE),
-                    project=role_assignment.get(self.PROJECT),
-                    user=user_id
-                )
-            elif role_assignment.get(self.DOMAIN) is not None:
-                self.client().roles.revoke(
-                    role=role_assignment.get(self.ROLE),
-                    domain=role_assignment.get(self.DOMAIN),
-                    user=user_id
-                )
+            if role_assignment in current_assignments:
+                if role_assignment.get(self.PROJECT) is not None:
+                    self.client().roles.revoke(
+                        role=role_assignment.get(self.ROLE),
+                        project=role_assignment.get(self.PROJECT),
+                        user=user_id
+                    )
+                elif role_assignment.get(self.DOMAIN) is not None:
+                    self.client().roles.revoke(
+                        role=role_assignment.get(self.ROLE),
+                        domain=role_assignment.get(self.DOMAIN),
+                        user=user_id
+                    )
 
     def _normalize_to_id(self, role_assignment_prps):
         role_assignments = []
@@ -259,7 +263,7 @@ class KeystoneRoleAssignmentMixin(object):
             (new_role_assignments,
              removed_role_assignments) = self._find_differences(
                 prop_diff.get(self.ROLES),
-                self._stored_properties_data.get(self.ROLES))
+                self.properties[self.ROLES])
 
             if len(new_role_assignments) > 0:
                 if user_id is not None:
@@ -272,27 +276,33 @@ class KeystoneRoleAssignmentMixin(object):
                         new_role_assignments)
 
             if len(removed_role_assignments) > 0:
+                current_assignments = self.parse_list_assignments(
+                    user_id=user_id, group_id=group_id)
                 if user_id is not None:
                     self._remove_role_assignments_from_user(
                         user_id,
-                        removed_role_assignments)
+                        removed_role_assignments,
+                        current_assignments)
                 elif group_id is not None:
                     self._remove_role_assignments_from_group(
                         group_id,
-                        removed_role_assignments)
+                        removed_role_assignments,
+                        current_assignments)
 
     def delete_assignment(self, user_id=None, group_id=None):
-        if self._stored_properties_data.get(self.ROLES) is not None:
+        if self.properties[self.ROLES] is not None:
+            current_assignments = self.parse_list_assignments(
+                user_id=user_id, group_id=group_id)
             if user_id is not None:
                 self._remove_role_assignments_from_user(
                     user_id,
-                    (self._stored_properties_data.
-                     get(self.ROLES)))
+                    (self.properties[self.ROLES]),
+                    current_assignments)
             elif group_id is not None:
                 self._remove_role_assignments_from_group(
                     group_id,
-                    (self._stored_properties_data.
-                     get(self.ROLES)))
+                    (self.properties[self.ROLES]),
+                    current_assignments)
 
     def validate_assignment_properties(self):
         if self.properties.get(self.ROLES) is not None:
@@ -309,6 +319,30 @@ class KeystoneRoleAssignmentMixin(object):
                             ' role %s') % role_assignment.get(self.ROLE)
                     raise exception.StackValidationFailed(message=msg)
 
+    def parse_list_assignments(self, user_id=None, group_id=None):
+        """Method used for get_live_state implementation in other resources."""
+        assignments = []
+        roles = []
+        if user_id is not None:
+            assignments = self.client().role_assignments.list(user=user_id)
+        elif group_id is not None:
+            assignments = self.client().role_assignments.list(group=group_id)
+        for assignment in assignments:
+            values = assignment.to_dict()
+            if not values.get('role') or not values.get('role').get('id'):
+                continue
+            role = {
+                self.ROLE: values['role']['id'],
+                self.DOMAIN: (values.get('scope') and
+                              values['scope'].get('domain') and
+                              values['scope'].get('domain').get('id')),
+                self.PROJECT: (values.get('scope') and
+                               values['scope'].get('project') and
+                               values['scope'].get('project').get('id')),
+            }
+            roles.append(role)
+        return roles
+
 
 class KeystoneUserRoleAssignment(resource.Resource,
                                  KeystoneRoleAssignmentMixin):
@@ -342,9 +376,6 @@ class KeystoneUserRoleAssignment(resource.Resource,
     properties_schema.update(
         KeystoneRoleAssignmentMixin.mixin_properties_schema)
 
-    def __init__(self, *args, **kwargs):
-        super(KeystoneUserRoleAssignment, self).__init__(*args, **kwargs)
-
     def client(self):
         return super(KeystoneUserRoleAssignment, self).client().client
 
@@ -403,9 +434,6 @@ class KeystoneGroupRoleAssignment(resource.Resource,
     properties_schema.update(
         KeystoneRoleAssignmentMixin.mixin_properties_schema)
 
-    def __init__(self, *args, **kwargs):
-        super(KeystoneGroupRoleAssignment, self).__init__(*args, **kwargs)
-
     def client(self):
         return super(KeystoneGroupRoleAssignment, self).client().client
 
