@@ -11,8 +11,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from heat.common import exception
 from heat.common.i18n import _
 from heat.engine import attributes
@@ -24,6 +22,10 @@ from heat.engine.resources.openstack.neutron import neutron
 from heat.engine import support
 from heat.engine import translation
 
+DEPR_MSG = _('Neutron LBaaS v1 is deprecated in the Liberty release '
+             'and is planned to be removed in a future release. '
+             'Going forward, the LBaaS V2 should be used.')
+
 
 class HealthMonitor(neutron.NeutronResource):
     """A resource for managing health monitors for loadbalancers in Neutron.
@@ -41,6 +43,10 @@ class HealthMonitor(neutron.NeutronResource):
 
     required_service_extension = 'lbaas'
 
+    support_status = support.SupportStatus(
+        support.DEPRECATED, DEPR_MSG, version='7.0.0'
+    )
+
     PROPERTIES = (
         DELAY, TYPE, MAX_RETRIES, TIMEOUT, ADMIN_STATE_UP,
         HTTP_METHOD, EXPECTED_CODES, URL_PATH,
@@ -60,8 +66,8 @@ class HealthMonitor(neutron.NeutronResource):
     properties_schema = {
         DELAY: properties.Schema(
             properties.Schema.INTEGER,
-            _('The minimum time in seconds between regular connections of '
-              'the member.'),
+            _('The minimum time in milliseconds between regular connections '
+              'of the member.'),
             required=True,
             update_allowed=True
         ),
@@ -82,7 +88,7 @@ class HealthMonitor(neutron.NeutronResource):
         ),
         TIMEOUT: properties.Schema(
             properties.Schema.INTEGER,
-            _('Maximum number of seconds for a monitor to wait for a '
+            _('Maximum number of milliseconds for a monitor to wait for a '
               'connection to be established before it times out.'),
             required=True,
             update_allowed=True
@@ -119,7 +125,7 @@ class HealthMonitor(neutron.NeutronResource):
             type=attributes.Schema.STRING
         ),
         DELAY_ATTR: attributes.Schema(
-            _('The minimum time in seconds between regular connections '
+            _('The minimum time in milliseconds between regular connections '
               'of the member.'),
             type=attributes.Schema.STRING
         ),
@@ -139,7 +145,7 @@ class HealthMonitor(neutron.NeutronResource):
             type=attributes.Schema.STRING
         ),
         TIMEOUT_ATTR: attributes.Schema(
-            _('Maximum number of seconds for a monitor to wait for a '
+            _('Maximum number of milliseconds for a monitor to wait for a '
               'connection to be established before it times out.'),
             type=attributes.Schema.STRING
         ),
@@ -196,6 +202,10 @@ class Pool(neutron.NeutronResource):
 
     required_service_extension = 'lbaas'
 
+    support_status = support.SupportStatus(
+        support.DEPRECATED, DEPR_MSG, version='7.0.0'
+    )
+
     PROPERTIES = (
         PROTOCOL, SUBNET_ID, SUBNET, LB_METHOD, NAME, DESCRIPTION,
         ADMIN_STATE_UP, VIP, MONITORS, PROVIDER,
@@ -418,6 +428,22 @@ class Pool(neutron.NeutronResource):
                 translation.TranslationRule.REPLACE,
                 [self.SUBNET],
                 value_path=[self.SUBNET_ID]
+            ),
+            translation.TranslationRule(
+                props,
+                translation.TranslationRule.RESOLVE,
+                [self.SUBNET],
+                client_plugin=self.client_plugin(),
+                finder='find_resourceid_by_name_or_id',
+                entity='subnet'
+            ),
+            translation.TranslationRule(
+                props,
+                translation.TranslationRule.RESOLVE,
+                [self.VIP, self.VIP_SUBNET],
+                client_plugin=self.client_plugin(),
+                finder='find_resourceid_by_name_or_id',
+                entity='subnet'
             )
         ]
 
@@ -443,8 +469,8 @@ class Pool(neutron.NeutronResource):
         properties = self.prepare_properties(
             self.properties,
             self.physical_resource_name())
-        self.client_plugin().resolve_subnet(
-            properties, self.SUBNET, 'subnet_id')
+        subnet_id = properties.pop(self.SUBNET)
+        properties['subnet_id'] = subnet_id
         vip_properties = properties.pop(self.VIP)
         monitors = properties.pop(self.MONITORS)
 
@@ -467,10 +493,9 @@ class Pool(neutron.NeutronResource):
         vip_arguments['protocol'] = self.properties[self.PROTOCOL]
 
         if vip_arguments.get(self.VIP_SUBNET) is None:
-            vip_arguments['subnet_id'] = properties[self.SUBNET_ID]
+            vip_arguments['subnet_id'] = subnet_id
         else:
-            vip_arguments['subnet_id'] = self.client_plugin().resolve_subnet(
-                vip_arguments, self.VIP_SUBNET, 'subnet_id')
+            vip_arguments['subnet_id'] = vip_arguments.pop(self.VIP_SUBNET)
 
         vip_arguments['pool_id'] = pool['id']
         vip = self.client().create_vip({'vip': vip_arguments})['vip']
@@ -579,7 +604,10 @@ class PoolMember(neutron.NeutronResource):
 
     required_service_extension = 'lbaas'
 
-    support_status = support.SupportStatus(version='2014.1')
+    support_status = support.SupportStatus(
+        support.DEPRECATED, DEPR_MSG, version='7.0.0',
+        previous_status=support.SupportStatus(version='2014.1')
+    )
 
     PROPERTIES = (
         POOL_ID, ADDRESS, PROTOCOL_PORT, WEIGHT, ADMIN_STATE_UP,
@@ -708,6 +736,11 @@ class LoadBalancer(resource.Resource):
 
     required_service_extension = 'lbaas'
 
+    support_status = support.SupportStatus(
+        support.DEPRECATED, DEPR_MSG, version='7.0.0',
+        previous_status=support.SupportStatus(version='2014.1')
+    )
+
     PROPERTIES = (
         POOL_ID, PROTOCOL_PORT, MEMBERS,
     ) = (
@@ -765,7 +798,7 @@ class LoadBalancer(resource.Resource):
                  new_props[self.MEMBERS] is not None)):
             members = set(new_props[self.MEMBERS] or [])
             rd_members = self.data()
-            old_members = set(six.iterkeys(rd_members))
+            old_members = set(rd_members)
             for member in old_members - members:
                 member_id = rd_members[member]
                 with self.client_plugin().ignore_not_found:
