@@ -26,6 +26,7 @@ from heat.common.i18n import _
 from heat.common.i18n import _LI
 from heat.db.sqlalchemy import api as db_api
 from heat.engine import api
+from heat.engine import resource
 from heat.engine import scheduler
 from heat.engine import software_config_io as swc_io
 from heat.objects import resource as resource_objects
@@ -100,7 +101,7 @@ class SoftwareConfigService(object):
     def _push_metadata_software_deployments(
             self, cnxt, server_id, stack_user_project_id):
         rs = db_api.resource_get_by_physical_resource_id(cnxt, server_id)
-        if not rs:
+        if not rs or rs.action == resource.Resource.DELETE:
             return
         cnxt.session.refresh(rs)
         deployments = self.metadata_software_deployments(cnxt, server_id)
