@@ -84,9 +84,6 @@ class TestInitialGroupSize(common.HeatTestCase):
         ('14n', dict(mins=1, maxs=4, desired=None, expected=1)),
     ]
 
-    def setUp(self):
-        super(TestInitialGroupSize, self).setUp()
-
     def test_initial_size(self):
         t = template_format.parse(inline_templates.as_heat_template)
         properties = t['resources']['my-group']['properties']
@@ -113,10 +110,9 @@ class TestGroupAdjust(common.HeatTestCase):
         self.assertIsNone(self.group.validate())
 
     def test_scaling_policy_cooldown_toosoon(self):
-        """If _is_scaling_allowed() returns False don't progress."""
         dont_call = self.patchobject(self.group, 'resize')
-        self.patchobject(self.group, '_is_scaling_allowed',
-                         return_value=False)
+        self.patchobject(self.group, '_check_scaling_allowed',
+                         side_effect=resource.NoActionRequired)
         self.assertRaises(resource.NoActionRequired,
                           self.group.adjust, 1)
         self.assertEqual([], dont_call.call_args_list)
@@ -140,8 +136,7 @@ class TestGroupAdjust(common.HeatTestCase):
         resize = self.patchobject(self.group, 'resize')
         finished_scaling = self.patchobject(self.group, '_finished_scaling')
         notify = self.patch('heat.engine.notification.autoscaling.send')
-        self.patchobject(self.group, '_is_scaling_allowed',
-                         return_value=True)
+        self.patchobject(self.group, '_check_scaling_allowed')
         self.group.adjust(33, adjustment_type='PercentChangeInCapacity',
                           min_adjustment_step=2)
 
@@ -172,8 +167,7 @@ class TestGroupAdjust(common.HeatTestCase):
         resize = self.patchobject(self.group, 'resize')
         finished_scaling = self.patchobject(self.group, '_finished_scaling')
         notify = self.patch('heat.engine.notification.autoscaling.send')
-        self.patchobject(self.group, '_is_scaling_allowed',
-                         return_value=True)
+        self.patchobject(self.group, '_check_scaling_allowed')
         self.group.adjust(-33, adjustment_type='PercentChangeInCapacity',
                           min_adjustment_step=2)
 
@@ -204,8 +198,7 @@ class TestGroupAdjust(common.HeatTestCase):
         resize = self.patchobject(self.group, 'resize')
         finished_scaling = self.patchobject(self.group, '_finished_scaling')
         notify = self.patch('heat.engine.notification.autoscaling.send')
-        self.patchobject(self.group, '_is_scaling_allowed',
-                         return_value=True)
+        self.patchobject(self.group, '_check_scaling_allowed')
         self.group.adjust(1)
 
         expected_notifies = [
@@ -234,8 +227,7 @@ class TestGroupAdjust(common.HeatTestCase):
         self.patchobject(self.group, 'resize',
                          side_effect=ValueError('test error'))
         notify = self.patch('heat.engine.notification.autoscaling.send')
-        self.patchobject(self.group, '_is_scaling_allowed',
-                         return_value=True)
+        self.patchobject(self.group, '_check_scaling_allowed')
         self.patchobject(self.group, '_finished_scaling')
         self.assertRaises(ValueError, self.group.adjust, 1)
 
@@ -264,8 +256,7 @@ class TestGroupAdjust(common.HeatTestCase):
         self.patchobject(self.group, 'resize',
                          side_effect=ValueError('test error'))
         notify = self.patch('heat.engine.notification.autoscaling.send')
-        self.patchobject(self.group, '_is_scaling_allowed',
-                         return_value=True)
+        self.patchobject(self.group, '_check_scaling_allowed')
         self.patchobject(self.group, '_finished_scaling')
 
         self.assertRaises(ValueError, self.group.adjust,
@@ -526,7 +517,7 @@ class RollingUpdatePolicyTest(common.HeatTestCase):
         tmpl_batch_sz = int(tmpl_policy['max_batch_size'])
         policy = stack['my-group'].properties['rolling_updates']
         self.assertTrue(policy)
-        self.assertTrue(len(policy) == 3)
+        self.assertEqual(3, len(policy))
         self.assertEqual(1, int(policy['min_in_service']))
         self.assertEqual(tmpl_batch_sz, int(policy['max_batch_size']))
         self.assertEqual(1, policy['pause_time'])
