@@ -19,6 +19,7 @@ import six
 
 from heat.common import exception
 from heat.common import template_format
+from heat.engine import resource
 from heat.engine.resources.aws.autoscaling import scaling_policy as aws_sp
 from heat.engine import scheduler
 from heat.tests.autoscaling import inline_templates
@@ -31,9 +32,6 @@ as_params = inline_templates.as_params
 
 
 class TestAutoScalingPolicy(common.HeatTestCase):
-    def setUp(self):
-        super(TestAutoScalingPolicy, self).setUp()
-
     def create_scaling_policy(self, t, stack, resource_name):
         rsrc = stack[resource_name]
         self.assertIsNone(rsrc.validate())
@@ -80,31 +78,51 @@ class TestAutoScalingPolicy(common.HeatTestCase):
         self.assertIn('Alarm WebServerScaleUpPolicy could '
                       'not find scaling group', six.text_type(ex))
 
-    def test_scaling_policy_not_alarm_state(self):
-        """If the details don't have 'alarm' then don't progress."""
+    def test_scaling_policy_adjust_no_action(self):
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
-        pol = self.create_scaling_policy(t, stack, 'WebServerScaleUpPolicy')
+        up_policy = self.create_scaling_policy(t, stack,
+                                               'WebServerScaleUpPolicy')
+        group = stack['WebServerGroup']
+        self.patchobject(group, 'adjust',
+                         side_effect=resource.NoActionRequired())
+        mock_fin_scaling = self.patchobject(up_policy, '_finished_scaling')
+        with mock.patch.object(up_policy,
+                               '_check_scaling_allowed') as mock_isa:
+            self.assertRaises(resource.NoActionRequired,
+                              up_policy.handle_signal)
+            mock_isa.assert_called_once_with()
+            mock_fin_scaling.assert_called_once_with('ChangeInCapacity : 1',
+                                                     size_changed=False)
 
-        test = {'current': 'not_an_alarm'}
-        with mock.patch.object(pol, '_is_scaling_allowed',
-                               side_effect=AssertionError()) as dont_call:
-            self.assertRaises(exception.NoActionRequired,
-                              pol.handle_signal, details=test)
-            self.assertEqual([], dont_call.call_args_list)
+    def test_scaling_policy_adjust_size_changed(self):
+        t = template_format.parse(as_template)
+        stack = utils.parse_stack(t, params=as_params)
+        up_policy = self.create_scaling_policy(t, stack,
+                                               'WebServerScaleUpPolicy')
+        group = stack['WebServerGroup']
+        self.patchobject(group, 'adjust')
+        mock_fin_scaling = self.patchobject(up_policy, '_finished_scaling')
+        with mock.patch.object(up_policy,
+                               '_check_scaling_allowed') as mock_isa:
+            self.assertIsNone(up_policy.handle_signal())
+            mock_isa.assert_called_once_with()
+            mock_fin_scaling.assert_called_once_with('ChangeInCapacity : 1',
+                                                     size_changed=True)
 
     def test_scaling_policy_cooldown_toosoon(self):
-        """If _is_scaling_allowed() returns False don't progress."""
         t = template_format.parse(as_template)
         stack = utils.parse_stack(t, params=as_params)
         pol = self.create_scaling_policy(t, stack, 'WebServerScaleUpPolicy')
+        group = stack['WebServerGroup']
         test = {'current': 'alarm'}
 
-        with mock.patch.object(pol.stack, 'resource_by_refid',
+        with mock.patch.object(group, 'adjust',
                                side_effect=AssertionError) as dont_call:
-            with mock.patch.object(pol, '_is_scaling_allowed',
-                                   return_value=False) as mock_isa:
-                self.assertRaises(exception.NoActionRequired,
+            with mock.patch.object(
+                    pol, '_check_scaling_allowed',
+                    side_effect=resource.NoActionRequired) as mock_isa:
+                self.assertRaises(resource.NoActionRequired,
                                   pol.handle_signal, details=test)
                 mock_isa.assert_called_once_with()
             self.assertEqual([], dont_call.call_args_list)
@@ -117,8 +135,7 @@ class TestAutoScalingPolicy(common.HeatTestCase):
 
         group = self.patchobject(pol.stack, 'resource_by_refid').return_value
         group.name = 'fluffy'
-        with mock.patch.object(pol, '_is_scaling_allowed',
-                               return_value=True) as mock_isa:
+        with mock.patch.object(pol, '_check_scaling_allowed') as mock_isa:
             pol.handle_signal(details=test)
             mock_isa.assert_called_once_with()
         group.adjust.assert_called_once_with(1, 'ChangeInCapacity', None)
@@ -153,9 +170,6 @@ class TestAutoScalingPolicy(common.HeatTestCase):
 
 
 class TestCooldownMixin(common.HeatTestCase):
-    def setUp(self):
-        super(TestCooldownMixin, self).setUp()
-
     def create_scaling_policy(self, t, stack, resource_name):
         rsrc = stack[resource_name]
         self.assertIsNone(rsrc.validate())
@@ -172,7 +186,9 @@ class TestCooldownMixin(common.HeatTestCase):
         previous_meta = {'cooldown': {
             now.isoformat(): 'ChangeInCapacity : 1'}}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertFalse(pol._is_scaling_allowed())
+        ex = self.assertRaises(resource.NoActionRequired,
+                               pol._check_scaling_allowed)
+        self.assertIn('due to cooldown', six.text_type(ex))
 
     def test_cooldown_is_in_progress_scaling_unfinished(self):
         t = template_format.parse(as_template)
@@ -181,7 +197,9 @@ class TestCooldownMixin(common.HeatTestCase):
 
         previous_meta = {'scaling_in_progress': True}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertFalse(pol._is_scaling_allowed())
+        ex = self.assertRaises(resource.NoActionRequired,
+                               pol._check_scaling_allowed)
+        self.assertIn('due to scaling activity', six.text_type(ex))
 
     def test_cooldown_not_in_progress(self):
         t = template_format.parse(as_template)
@@ -196,7 +214,7 @@ class TestCooldownMixin(common.HeatTestCase):
             'scaling_in_progress': False
         }
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertTrue(pol._is_scaling_allowed())
+        self.assertIsNone(pol._check_scaling_allowed())
 
     def test_scaling_policy_cooldown_zero(self):
         t = template_format.parse(as_template)
@@ -211,7 +229,7 @@ class TestCooldownMixin(common.HeatTestCase):
         now = timeutils.utcnow()
         previous_meta = {now.isoformat(): 'ChangeInCapacity : 1'}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertTrue(pol._is_scaling_allowed())
+        self.assertIsNone(pol._check_scaling_allowed())
 
     def test_scaling_policy_cooldown_none(self):
         t = template_format.parse(as_template)
@@ -227,7 +245,7 @@ class TestCooldownMixin(common.HeatTestCase):
         now = timeutils.utcnow()
         previous_meta = {now.isoformat(): 'ChangeInCapacity : 1'}
         self.patchobject(pol, 'metadata_get', return_value=previous_meta)
-        self.assertTrue(pol._is_scaling_allowed())
+        self.assertIsNone(pol._check_scaling_allowed())
 
     def test_metadata_is_written(self):
         t = template_format.parse(as_template)
