@@ -86,8 +86,6 @@ class TestContainer(common.HeatTestCase):
 
     def setUp(self):
         super(TestContainer, self).setUp()
-        utils.setup_dummy_db()
-        self.ctx = utils.dummy_context()
 
         self.patcher_client = mock.patch.object(
             container.GenericContainer, 'client')
@@ -112,7 +110,7 @@ class TestContainer(common.HeatTestCase):
             self.stack = utils.parse_stack(tmpl)
         else:
             self.stack = stack
-        resource_defns = self.stack.t.resource_definitions(stack)
+        resource_defns = self.stack.t.resource_definitions(self.stack)
         if snippet is None:
             snippet = resource_defns['container']
         res_class = container.resource_mapping()[tmpl_name]
@@ -182,8 +180,6 @@ class TestContainer(common.HeatTestCase):
         mock_container.container_ref = 'test-container-ref'
         mock_container.secret_refs = {'name': 'ref'}
         mock_container.consumers = [{'name': 'name1', 'ref': 'ref1'}]
-        mock_container._get_formatted_entity.return_value = (
-            ('attr', ), ('v',))
         res = self._create_resource('foo')
         self.client.containers.get.return_value = mock_container
         self.assertEqual('test-status', res.FnGetAtt('status'))
@@ -191,7 +187,6 @@ class TestContainer(common.HeatTestCase):
         self.assertEqual({'name': 'ref'}, res.FnGetAtt('secret_refs'))
         self.assertEqual([{'name': 'name1', 'ref': 'ref1'}],
                          res.FnGetAtt('consumers'))
-        self.assertEqual({'attr': 'v'}, res.FnGetAtt('show'))
 
     def test_check_create_complete(self):
         tmpl = template_format.parse(template_by_name())
