@@ -21,8 +21,9 @@ from neutronclient.v2_0 import client as neutronclient
 
 from heat.common import exception
 from heat.common import template_format
-from heat.engine.cfn import functions as cfn_funcs
+from heat.common import timeutils
 from heat.engine.clients.os import neutron
+from heat.engine.hot import functions as hot_funcs
 from heat.engine import rsrc_defn
 from heat.engine import scheduler
 from heat.engine import stack as parser
@@ -131,6 +132,7 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         self.m.StubOutWithMock(neutronclient.Client, 'show_port')
         self.m.StubOutWithMock(neutronV20,
                                'find_resourceid_by_name_or_id')
+        self.m.StubOutWithMock(timeutils, 'retry_backoff_delay')
         self.patchobject(neutron.NeutronClientPlugin, 'has_extension',
                          return_value=True)
 
@@ -194,13 +196,31 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         ).AndRaise(qe.NeutronClientException(status_code=404))
         neutronclient.Client.show_floatingip(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
-        ).MultipleTimes().AndReturn({'floatingip': {
+        ).AndReturn({'floatingip': {
+            'id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
+            'floating_network_id': u'abcd1234'
+        }})
+        neutronclient.Client.show_floatingip(
+            'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
+        ).AndReturn({'floatingip': {
             'id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
             'floating_network_id': u'abcd1234'
         }})
 
+        timeutils.retry_backoff_delay(1, jitter_max=2.0).AndReturn(0.01)
         neutronclient.Client.delete_floatingip(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766').AndReturn(None)
+        neutronclient.Client.show_floatingip(
+            'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
+        ).AndReturn({'floatingip': {
+            'id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
+            'floating_network_id': u'abcd1234'
+        }})
+        neutronclient.Client.delete_floatingip(
+            'fc68ea2c-b60b-4b4f-bd82-94ec81110766').AndReturn(None)
+        neutronclient.Client.show_floatingip(
+            'fc68ea2c-b60b-4b4f-bd82-94ec81110766').AndRaise(
+                qe.NeutronClientException(status_code=404))
         neutronclient.Client.delete_floatingip(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766').AndRaise(
                 qe.NeutronClientException(status_code=404))
@@ -388,6 +408,9 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         neutronclient.Client.delete_floatingip(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
         ).AndReturn(None)
+        neutronclient.Client.show_floatingip(
+            'fc68ea2c-b60b-4b4f-bd82-94ec81110766').AndRaise(
+                qe.NeutronClientException(status_code=404))
 
         neutronclient.Client.delete_port(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
@@ -461,21 +484,11 @@ class NeutronFloatingIPTest(common.HeatTestCase):
 
         self.m.VerifyAll()
 
-    def _test_floating_dependancy(self):
-        neutronV20.find_resourceid_by_name_or_id(
-            mox.IsA(neutronclient.Client),
-            'router',
-            'subnet_uuid',
-            cmd_resource=None,
-        ).MultipleTimes().AndReturn('subnet_uuid')
-        self.m.ReplayAll()
-
     def test_floatip_port_dependency_subnet(self):
-        self._test_floating_dependancy()
         t = template_format.parse(neutron_floating_no_assoc_template)
         stack = utils.parse_stack(t)
 
-        p_result = self.patchobject(cfn_funcs.ResourceRef, 'result')
+        p_result = self.patchobject(hot_funcs.GetResource, 'result')
         p_result.return_value = 'subnet_uuid'
         # check dependencies for fip resource
         required_by = set(stack.dependencies.required_by(
@@ -484,7 +497,6 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         self.m.VerifyAll()
 
     def test_floatip_port_dependency_network(self):
-        self._test_floating_dependancy()
         t = template_format.parse(neutron_floating_no_assoc_template)
         del t['resources']['port_floating']['properties']['fixed_ips']
         stack = utils.parse_stack(t)
@@ -492,7 +504,7 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         p_show = self.patchobject(neutronclient.Client, 'show_network')
         p_show.return_value = {'network': {'subnets': ['subnet_uuid']}}
 
-        p_result = self.patchobject(cfn_funcs.ResourceRef, 'result',
+        p_result = self.patchobject(hot_funcs.GetResource, 'result',
                                     autospec=True)
 
         def return_uuid(self):
@@ -527,7 +539,7 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         }})
         neutronclient.Client.show_floatingip(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
-        ).MultipleTimes().AndReturn({'floatingip': {
+        ).AndReturn({'floatingip': {
             'status': 'ACTIVE',
             'id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
             'floating_ip_address': '172.24.4.98'
@@ -545,6 +557,36 @@ class NeutronFloatingIPTest(common.HeatTestCase):
 
         self.m.VerifyAll()
 
+    def test_floatingip_create_specify_dns(self):
+        neutronV20.find_resourceid_by_name_or_id(
+            mox.IsA(neutronclient.Client),
+            'network',
+            'abcd1234',
+            cmd_resource=None,
+        ).MultipleTimes().AndReturn('abcd1234')
+        self.stub_NetworkConstraint_validate()
+        neutronclient.Client.create_floatingip({
+            'floatingip': {'floating_network_id': u'abcd1234',
+                           'dns_name': 'myvm',
+                           'dns_domain': 'openstack.org.'}
+        }).AndReturn({'floatingip': {
+            'status': 'ACTIVE',
+            'id': 'fc68ea2c-b60b-4b4f-bd82-94ec81110766',
+            'floating_ip_address': '172.24.4.98'
+        }})
+
+        self.m.ReplayAll()
+        t = template_format.parse(neutron_floating_template)
+        props = t['resources']['floating_ip']['properties']
+        props['dns_name'] = 'myvm'
+        props['dns_domain'] = 'openstack.org.'
+        stack = utils.parse_stack(t)
+        fip = stack['floating_ip']
+        scheduler.TaskRunner(fip.create)()
+        self.assertEqual((fip.CREATE, fip.COMPLETE), fip.state)
+
+        self.m.VerifyAll()
+
     def test_floatip_port(self):
         t = template_format.parse(neutron_floating_no_assoc_template)
         t['resources']['port_floating']['properties']['network'] = "xyz1234"
@@ -626,6 +668,9 @@ class NeutronFloatingIPTest(common.HeatTestCase):
         neutronclient.Client.delete_floatingip(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
         ).AndReturn(None)
+        neutronclient.Client.show_floatingip(
+            'fc68ea2c-b60b-4b4f-bd82-94ec81110766').AndRaise(
+                qe.NeutronClientException(status_code=404))
 
         neutronclient.Client.delete_port(
             'fc68ea2c-b60b-4b4f-bd82-94ec81110766'
