@@ -38,6 +38,9 @@ resources:
     properties:
       name: SenlinCluster
       profile: fake_profile
+      policies:
+        - policy: fake_policy
+          enabled: true
       min_size: 0
       max_size: -1
       desired_capacity: 1
@@ -60,6 +63,9 @@ class FakeCluster(object):
         self.timeout = 3600
         self.max_size = -1
         self.min_size = 0
+        self.location = 'actions/fake-action'
+        self.profile_name = 'fake_profile'
+        self.profile_id = 'fake_profile_id'
 
     def to_dict(self):
         return {
@@ -72,7 +78,9 @@ class FakeCluster(object):
             'desired_capacity': self.desired_capacity,
             'max_size': self.max_size,
             'min_size': self.min_size,
-            'nodes': self.nodes
+            'nodes': self.nodes,
+            'profile_name': self.profile_name,
+            'profile_id': self.profile_id
         }
 
 
@@ -80,9 +88,16 @@ class SenlinClusterTest(common.HeatTestCase):
     def setUp(self):
         super(SenlinClusterTest, self).setUp()
         self.senlin_mock = mock.MagicMock()
+        self.senlin_mock.get_profile.return_value = mock.Mock(
+            id='fake_profile_id'
+        )
         self.patchobject(sc.Cluster, 'client', return_value=self.senlin_mock)
+        self.patchobject(senlin.SenlinClientPlugin, 'client',
+                         return_value=self.senlin_mock)
         self.patchobject(senlin.ProfileConstraint, 'validate',
                          return_value=True)
+        self.patchobject(senlin.PolicyConstraint, 'validate',
+                         return_value=True)
         self.fake_cl = FakeCluster()
         self.t = template_format.parse(cluster_stack_template)
 
@@ -95,6 +110,14 @@ class SenlinClusterTest(common.HeatTestCase):
         cluster = self._init_cluster(template)
         self.senlin_mock.create_cluster.return_value = self.fake_cl
         self.senlin_mock.get_cluster.return_value = self.fake_cl
+        self.senlin_mock.get_action.return_value = mock.Mock(
+            status='SUCCEEDED')
+        self.senlin_mock.get_policy.return_value = mock.Mock(
+            id='fake_policy_id'
+        )
+        self.senlin_mock.cluster_policies.return_value = [
+            {'policy_id': 'fake_policy_id', 'enabled': True}
+        ]
         scheduler.TaskRunner(cluster.create)()
         self.assertEqual((cluster.CREATE, cluster.COMPLETE),
                          cluster.state)
@@ -103,29 +126,40 @@ class SenlinClusterTest(common.HeatTestCase):
 
     def test_cluster_create_success(self):
         self._create_cluster(self.t)
-        expect_kwargs = {
+        create_cluster_kwargs = {
             'name': 'SenlinCluster',
-            'profile_id': 'fake_profile',
+            'profile_id': 'fake_profile_id',
             'desired_capacity': 1,
             'min_size': 0,
             'max_size': -1,
             'metadata': {'foo': 'bar'},
             'timeout': 3600,
         }
+        attach_policy_kwargs = {
+            'cluster': self.fake_cl.id,
+            'policy': 'fake_policy_id',
+            'enabled': True
+        }
         self.senlin_mock.create_cluster.assert_called_once_with(
-            **expect_kwargs)
-        self.senlin_mock.get_cluster.assert_called_once_with(self.fake_cl.id)
+            **create_cluster_kwargs)
+        self.senlin_mock.cluster_attach_policy.assert_called_once_with(
+            **attach_policy_kwargs)
 
     def test_cluster_create_error(self):
-        cfg.CONF.set_override('action_retry_limit', 0)
+        cfg.CONF.set_override('action_retry_limit', 0, enforce_type=True)
         cluster = self._init_cluster(self.t)
         self.senlin_mock.create_cluster.return_value = self.fake_cl
-        self.senlin_mock.get_cluster.return_value = FakeCluster(
-            status='ERROR')
+        mock_action = mock.MagicMock()
+        mock_action.status = 'FAILED'
+        mock_action.status_reason = 'oops'
+        self.senlin_mock.get_policy.return_value = mock.Mock(
+            id='fake_policy_id'
+        )
+        self.senlin_mock.get_action.return_value = mock_action
         create_task = scheduler.TaskRunner(cluster.create)
         ex = self.assertRaises(exception.ResourceFailure, create_task)
         expected = ('ResourceInError: resources.senlin-cluster: '
-                    'Went to status ERROR due to "Unknown"')
+                    'Went to status FAILED due to "oops"')
         self.assertEqual(expected, six.text_type(ex))
 
     def test_cluster_delete_success(self):
@@ -147,6 +181,12 @@ class SenlinClusterTest(common.HeatTestCase):
 
     def test_cluster_update_profile(self):
         cluster = self._create_cluster(self.t)
+        # Mock translate rules
+        self.senlin_mock.get_profile.side_effect = [
+            mock.Mock(id='new_profile_id'),
+            mock.Mock(id='fake_profile_id'),
+            mock.Mock(id='new_profile_id'),
+        ]
         new_t = copy.deepcopy(self.t)
         props = new_t['resources']['senlin-cluster']['properties']
         props['profile'] = 'new_profile'
@@ -160,13 +200,12 @@ class SenlinClusterTest(common.HeatTestCase):
         scheduler.TaskRunner(cluster.update, new_cluster)()
         self.assertEqual((cluster.UPDATE, cluster.COMPLETE), cluster.state)
         cluster_update_kwargs = {
-            'profile_id': 'new_profile',
+            'profile_id': 'new_profile_id',
             'name': 'new_name'
         }
         self.senlin_mock.update_cluster.assert_called_once_with(
-            cluster.resource_id, **cluster_update_kwargs)
-        self.senlin_mock.get_action.assert_called_once_with(
-            'fake-action')
+            cluster=self.fake_cl, **cluster_update_kwargs)
+        self.assertEqual(3, self.senlin_mock.get_action.call_count)
 
     def test_cluster_update_desire_capacity(self):
         cluster = self._create_cluster(self.t)
@@ -186,9 +225,64 @@ class SenlinClusterTest(common.HeatTestCase):
             'number': 10
         }
         self.senlin_mock.cluster_resize.assert_called_once_with(
-            cluster.resource_id, **cluster_resize_kwargs)
-        self.senlin_mock.get_action.assert_called_once_with(
-            'fake-action')
+            cluster=cluster.resource_id, **cluster_resize_kwargs)
+        self.assertEqual(3, self.senlin_mock.get_action.call_count)
+
+    def test_cluster_update_policy_add_remove(self):
+        cluster = self._create_cluster(self.t)
+        # Mock translate rules
+        self.senlin_mock.get_policy.side_effect = [
+            mock.Mock(id='new_policy_id'),
+            mock.Mock(id='fake_policy_id'),
+            mock.Mock(id='new_policy_id'),
+        ]
+        new_t = copy.deepcopy(self.t)
+        props = new_t['resources']['senlin-cluster']['properties']
+        props['policies'] = [{'policy': 'new_policy'}]
+        rsrc_defns = template.Template(new_t).resource_definitions(self.stack)
+        new_cluster = rsrc_defns['senlin-cluster']
+        self.senlin_mock.cluster_detach_policy.return_value = {
+            'action': 'fake-action'}
+        self.senlin_mock.cluster_attach_policy.return_value = {
+            'action': 'fake-action'}
+        self.senlin_mock.get_action.return_value = mock.Mock(
+            status='SUCCEEDED')
+        scheduler.TaskRunner(cluster.update, new_cluster)()
+        self.assertEqual((cluster.UPDATE, cluster.COMPLETE), cluster.state)
+        detach_policy_kwargs = {
+            'policy': 'fake_policy_id',
+            'cluster': cluster.resource_id,
+            'enabled': True,
+        }
+        self.assertEqual(2,
+                         self.senlin_mock.cluster_attach_policy.call_count)
+        self.senlin_mock.cluster_detach_policy.assert_called_once_with(
+            **detach_policy_kwargs)
+        self.assertEqual(0, self.senlin_mock.cluster_update_policy.call_count)
+        self.assertEqual(4, self.senlin_mock.get_action.call_count)
+
+    def test_cluster_update_policy_exists(self):
+        cluster = self._create_cluster(self.t)
+        new_t = copy.deepcopy(self.t)
+        props = new_t['resources']['senlin-cluster']['properties']
+        props['policies'] = [{'policy': 'fake_policy', 'enabled': False}]
+        rsrc_defns = template.Template(new_t).resource_definitions(self.stack)
+        new_cluster = rsrc_defns['senlin-cluster']
+        self.senlin_mock.cluster_update_policy.return_value = {
+            'action': 'fake-action'}
+        self.senlin_mock.get_action.return_value = mock.Mock(
+            status='SUCCEEDED')
+        scheduler.TaskRunner(cluster.update, new_cluster)()
+        self.assertEqual((cluster.UPDATE, cluster.COMPLETE), cluster.state)
+        update_policy_kwargs = {
+            'policy': 'fake_policy_id',
+            'cluster': cluster.resource_id,
+            'enabled': False,
+        }
+        self.senlin_mock.cluster_update_policy.assert_called_once_with(
+            **update_policy_kwargs)
+        self.assertEqual(1, self.senlin_mock.cluster_attach_policy.call_count)
+        self.assertEqual(0, self.senlin_mock.cluster_detach_policy.call_count)
 
     def test_cluster_update_failed(self):
         cluster = self._create_cluster(self.t)
@@ -208,6 +302,19 @@ class SenlinClusterTest(common.HeatTestCase):
                          'Went to status FAILED due to "Unknown"',
                          six.text_type(exc))
 
+    def test_cluster_get_attr_collect(self):
+        cluster = self._create_cluster(self.t)
+        self.senlin_mock.collect_cluster_attrs.return_value = [
+            mock.Mock(attr_value='ip1')]
+        attr_path1 = ['details.addresses.private[0].addr']
+        self.assertEqual(
+            ['ip1'], cluster.get_attribute(cluster.ATTR_COLLECT, *attr_path1))
+        attr_path2 = ['details.addresses.private[0].addr', 0]
+        self.assertEqual(
+            'ip1', cluster.get_attribute(cluster.ATTR_COLLECT, *attr_path2))
+        self.senlin_mock.collect_cluster_attrs.assert_called_with(
+            cluster.resource_id, attr_path2[0])
+
     def test_cluster_resolve_attribute(self):
         excepted_show = {
             'id': 'some_id',
@@ -219,7 +326,10 @@ class SenlinClusterTest(common.HeatTestCase):
             'desired_capacity': 1,
             'max_size': -1,
             'min_size': 0,
-            'nodes': ['node1']
+            'nodes': ['node1'],
+            'profile_name': 'fake_profile',
+            'profile_id': 'fake_profile_id',
+            'policies': [{'policy_id': 'fake_policy_id', 'enabled': True}]
         }
         cluster = self._create_cluster(self.t)
         self.assertEqual(self.fake_cl.desired_capacity,
@@ -229,6 +339,24 @@ class SenlinClusterTest(common.HeatTestCase):
         self.assertEqual(excepted_show,
                          cluster._show_resource())
 
+    def test_cluster_get_live_state(self):
+        expected_reality = {
+            'name': 'SenlinCluster',
+            'metadata': {'foo': 'bar'},
+            'timeout': 3600,
+            'desired_capacity': 1,
+            'max_size': -1,
+            'min_size': 0,
+            'profile': 'fake_profile_id',
+            'policies': [{'policy': 'fake_policy_id', 'enabled': True}]
+        }
+        cluster = self._create_cluster(self.t)
+        self.senlin_mock.get_cluster.return_value = self.fake_cl
+
+        reality = cluster.get_live_state(cluster.properties)
+
+        self.assertEqual(expected_reality, reality)
+
 
 class TestSenlinClusterValidation(common.HeatTestCase):
     def setUp(self):
