@@ -14,6 +14,8 @@
 import mock
 import six
 
+from six.moves.urllib import parse as urlparse
+
 from heat.common import template_format
 from heat.engine.clients import client_plugin
 from heat.engine import resource
@@ -101,8 +103,36 @@ class ZaqarMessageQueueTest(common.HeatTestCase):
         self.m.ReplayAll()
 
         scheduler.TaskRunner(queue.create)()
-        self.fc.api_url = 'http://127.0.0.1:8888/v1'
-        self.assertEqual('http://127.0.0.1:8888/v1/queues/myqueue',
+        self.fc.api_url = 'http://127.0.0.1:8888/'
+        self.fc.api_version = 1.1
+        self.assertEqual('http://127.0.0.1:8888/v1.1/queues/myqueue',
+                         queue.FnGetAtt('href'))
+
+        self.m.VerifyAll()
+
+    def test_create_default_name(self):
+        t = template_format.parse(wp_template)
+        del t['Resources']['MyQueue2']['Properties']['name']
+        self.parse_stack(t)
+
+        queue = self.stack['MyQueue2']
+        self.m.StubOutWithMock(queue, 'client')
+        queue.client().MultipleTimes().AndReturn(self.fc)
+
+        name_match = utils.PhysName(self.stack.name, 'MyQueue2')
+        self.m.StubOutWithMock(self.fc, 'queue')
+        self.fc.queue(name_match, auto_create=False).WithSideEffects(FakeQueue)
+
+        self.m.ReplayAll()
+
+        scheduler.TaskRunner(queue.create)()
+
+        queue_name = queue.physical_resource_name()
+        self.assertEqual(name_match, queue_name)
+
+        self.fc.api_url = 'http://127.0.0.1:8888'
+        self.fc.api_version = 2
+        self.assertEqual('http://127.0.0.1:8888/v2/queues/' + queue_name,
                          queue.FnGetAtt('href'))
 
         self.m.VerifyAll()
@@ -136,6 +166,9 @@ class ZaqarMessageQueueTest(common.HeatTestCase):
                 return mockclient()
 
         mock_def = mock.Mock(spec=rsrc_defn.ResourceDefinition)
+        props = mock.Mock()
+        props.props = {}
+        mock_def.properties.return_value = props
         mock_stack = mock.Mock()
         mock_stack.db_resource_get.return_value = None
         mock_stack.has_cache_data.return_value = False
@@ -270,3 +303,64 @@ class ZaqarMessageQueueTest(common.HeatTestCase):
                                            queue._show_resource()))
 
         self.m.VerifyAll()
+
+
+class ZaqarSignedQueueURLTest(common.HeatTestCase):
+    tmpl = '''
+heat_template_version: 2015-10-15
+resources:
+  signed_url:
+    type: OS::Zaqar::SignedQueueURL
+    properties:
+      queue: foo
+      ttl: 60
+      paths:
+        - messages
+        - subscription
+      methods:
+        - POST
+        - DELETE
+'''
+
+    @mock.patch('zaqarclient.queues.v2.queues.Queue.signed_url')
+    def test_create(self, mock_signed_url):
+        mock_signed_url.return_value = {
+            'expires': '2020-01-01',
+            'signature': 'secret',
+            'project': 'project_id',
+            'paths': ['/v2/foo/messages', '/v2/foo/sub'],
+            'methods': ['DELETE', 'POST']}
+
+        self.t = template_format.parse(self.tmpl)
+        self.stack = utils.parse_stack(self.t)
+        self.rsrc = self.stack['signed_url']
+        self.assertIsNone(self.rsrc.validate())
+        self.stack.create()
+        self.assertEqual(self.rsrc.CREATE, self.rsrc.action)
+        self.assertEqual(self.rsrc.COMPLETE, self.rsrc.status)
+        self.assertEqual(self.stack.CREATE, self.stack.action)
+        self.assertEqual(self.stack.COMPLETE, self.stack.status)
+
+        mock_signed_url.assert_called_once_with(
+            paths=['messages', 'subscription'],
+            methods=['POST', 'DELETE'],
+            ttl_seconds=60)
+
+        self.assertEqual('secret', self.rsrc.FnGetAtt('signature'))
+        self.assertEqual('2020-01-01', self.rsrc.FnGetAtt('expires'))
+        self.assertEqual('project_id', self.rsrc.FnGetAtt('project'))
+        self.assertEqual(['/v2/foo/messages', '/v2/foo/sub'],
+                         self.rsrc.FnGetAtt('paths'))
+        self.assertEqual(['DELETE', 'POST'], self.rsrc.FnGetAtt('methods'))
+        expected_query = {
+            'queue_name': ['foo'],
+            'expires': ['2020-01-01'],
+            'signature': ['secret'],
+            'project_id': ['project_id'],
+            'paths': ['/v2/foo/messages,/v2/foo/sub'],
+            'methods': ['DELETE,POST']
+        }
+        query_str_attr = self.rsrc.get_attribute('query_str')
+        self.assertEqual(expected_query,
+                         urlparse.parse_qs(query_str_attr,
+                                           strict_parsing=True))
