@@ -12,18 +12,18 @@
 #    under the License.
 
 import copy
-import fixtures
-from oslo_log import log as logging
 import time
 
-from keystoneclient import exceptions as kc_exceptions
+import fixtures
+from keystoneauth1 import exceptions as kc_exceptions
 import mock
+from oslo_log import log as logging
 
 from heat.common import exception
-from heat.common import heat_keystoneclient as hkc
 from heat.common import template_format
 from heat.common import timeutils
 from heat.engine.clients.os import keystone
+from heat.engine.clients.os.keystone import heat_keystoneclient as hkc
 from heat.engine import scheduler
 from heat.engine import stack
 from heat.engine import template
@@ -84,6 +84,46 @@ class StackTest(common.HeatTestCase):
         self.assertEqual([], snapshot_object.Snapshot.get_all(
             self.ctx, stack_id))
 
+    def test_delete_with_snapshot_after_stack_add_resource(self):
+        tpl = {'heat_template_version': 'ocata',
+               'resources':
+                   {'A': {'type': 'ResourceWithRestoreType'}}}
+        self.stack = stack.Stack(self.ctx, 'stack_delete_with_snapshot',
+                                 template.Template(tpl))
+        stack_id = self.stack.store()
+        self.stack.create()
+
+        data = copy.deepcopy(self.stack.prepare_abandon())
+        data['resources']['A']['resource_data']['a_string'] = 'foo'
+        snapshot_fake = {
+            'tenant': self.ctx.tenant_id,
+            'name': 'Snapshot',
+            'stack_id': stack_id,
+            'status': 'COMPLETE',
+            'data': data
+        }
+        snapshot_object.Snapshot.create(self.ctx, snapshot_fake)
+
+        self.assertIsNotNone(snapshot_object.Snapshot.get_all(
+            self.ctx, stack_id))
+
+        new_tmpl = {'heat_template_version': 'ocata',
+                    'resources':
+                        {'A': {'type': 'ResourceWithRestoreType'},
+                         'B': {'type': 'ResourceWithRestoreType'}}}
+        updated_stack = stack.Stack(self.ctx, 'update_stack_add_res',
+                                    template.Template(new_tmpl))
+        self.stack.update(updated_stack)
+        self.assertEqual(2, len(self.stack.resources))
+
+        self.stack.delete()
+        db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
+        self.assertIsNone(db_s)
+        self.assertEqual((stack.Stack.DELETE, stack.Stack.COMPLETE),
+                         self.stack.state)
+        self.assertEqual([], snapshot_object.Snapshot.get_all(
+            self.ctx, stack_id))
+
     def test_delete_user_creds(self):
         self.stack = stack.Stack(self.ctx, 'delete_test', self.tmpl)
         stack_id = self.stack.store()
@@ -92,14 +132,16 @@ class StackTest(common.HeatTestCase):
         self.assertIsNotNone(db_s)
         self.assertIsNotNone(db_s.user_creds_id)
         user_creds_id = db_s.user_creds_id
-        db_creds = ucreds_object.UserCreds.get_by_id(db_s.user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, db_s.user_creds_id)
         self.assertIsNotNone(db_creds)
 
         self.stack.delete()
 
         db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
         self.assertIsNone(db_s)
-        db_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, user_creds_id)
         self.assertIsNone(db_creds)
         del_db_s = stack_object.Stack.get_by_id(self.ctx,
                                                 stack_id,
@@ -122,7 +164,8 @@ class StackTest(common.HeatTestCase):
         self.assertIsNotNone(db_s)
         self.assertIsNotNone(db_s.user_creds_id)
         user_creds_id = db_s.user_creds_id
-        db_creds = ucreds_object.UserCreds.get_by_id(db_s.user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, db_s.user_creds_id)
         self.assertIsNotNone(db_creds)
 
         ucreds_object.UserCreds.delete(self.ctx, user_creds_id)
@@ -131,7 +174,8 @@ class StackTest(common.HeatTestCase):
 
         db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
         self.assertIsNone(db_s)
-        db_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
+        db_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, user_creds_id)
         self.assertIsNone(db_creds)
         del_db_s = stack_object.Stack.get_by_id(self.ctx,
                                                 stack_id,
@@ -192,7 +236,8 @@ class StackTest(common.HeatTestCase):
 
         user_creds_id = db_s.user_creds_id
         self.assertIsNotNone(user_creds_id)
-        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, user_creds_id)
         self.assertEqual('thetrustor', user_creds.get('trustor_user_id'))
 
         self.stack.delete()
@@ -223,7 +268,8 @@ class StackTest(common.HeatTestCase):
 
         user_creds_id = db_s.user_creds_id
         self.assertIsNotNone(user_creds_id)
-        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, user_creds_id)
         self.assertEqual('thetrustor', user_creds.get('trustor_user_id'))
 
         mock_kc.return_value = fakes.FakeKeystoneClient(user_id='nottrustor')
@@ -274,14 +320,16 @@ class StackTest(common.HeatTestCase):
         self.assertIsNotNone(db_s)
         user_creds_id = db_s.user_creds_id
         self.assertIsNotNone(user_creds_id)
-        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, user_creds_id)
         self.assertIsNotNone(user_creds)
 
         self.stack.delete()
 
         db_s = stack_object.Stack.get_by_id(self.ctx, stack_id)
         self.assertIsNone(db_s)
-        user_creds = ucreds_object.UserCreds.get_by_id(user_creds_id)
+        user_creds = ucreds_object.UserCreds.get_by_id(
+            self.ctx, user_creds_id)
         self.assertIsNotNone(user_creds)
         self.assertEqual((stack.Stack.DELETE, stack.Stack.COMPLETE),
                          self.stack.state)
