@@ -47,9 +47,10 @@ class JsonToYamlTest(common.HeatTestCase):
             if template_test_count >= self.expected_test_count:
                 break
 
-        self.assertTrue(template_test_count >= self.expected_test_count,
-                        'Expected at least %d templates to be tested, not %d' %
-                        (self.expected_test_count, template_test_count))
+        self.assertGreaterEqual(
+            template_test_count, self.expected_test_count,
+            'Expected at least %d templates to be tested, not %d' %
+            (self.expected_test_count, template_test_count))
 
     def compare_json_vs_yaml(self, json_str, yml_str):
         yml = template_format.parse(yml_str)
@@ -97,12 +98,13 @@ class YamlMinimalTest(common.HeatTestCase):
 
     def test_long_yaml(self):
         template = {'HeatTemplateFormatVersion': '2012-12-12'}
-        config.cfg.CONF.set_override('max_template_size', 10)
+        config.cfg.CONF.set_override('max_template_size', 10,
+                                     enforce_type=True)
         template['Resources'] = ['a'] * int(
             config.cfg.CONF.max_template_size / 3)
         limit = config.cfg.CONF.max_template_size
         long_yaml = yaml.safe_dump(template)
-        self.assertTrue(len(long_yaml) > limit)
+        self.assertGreater(len(long_yaml), limit)
         ex = self.assertRaises(exception.RequestLimitExceeded,
                                template_format.parse, long_yaml)
         msg = ('Request limit exceeded: Template size (%(actual_len)s '
@@ -201,7 +203,7 @@ class JsonYamlResolvedCompareTest(common.HeatTestCase):
         del(t2nr['Resources'])
         self.assertEqual(t1nr, t2nr)
 
-        self.assertEqual(set(six.iterkeys(stack1)), set(six.iterkeys(stack2)))
+        self.assertEqual(set(stack1), set(stack2))
         for key in stack1:
             self.assertEqual(stack1[key].t, stack2[key].t)
 
