@@ -465,10 +465,13 @@ class TestTranslationRule(common.HeatTestCase):
 
         self.assertIsNone(props.get('far'))
 
-    def _test_resolve_rule(self, is_list=False):
+    def _test_resolve_rule(self, is_list=False,
+                           check_error=False):
         class FakeClientPlugin(object):
             def find_name_id(self, entity=None,
                              src_value='far'):
+                if check_error:
+                    raise exception.NotFound()
                 if entity == 'rose':
                     return 'pink'
                 return 'yellow'
@@ -599,6 +602,20 @@ class TestTranslationRule(common.HeatTestCase):
         rule.execute_rule()
         self.assertEqual([], props.get('far'))
 
+    def test_resolve_rule_ignore_error(self):
+        client_plugin, schema = self._test_resolve_rule(check_error=True)
+        data = {'far': 'one'}
+        props = properties.Properties(schema, data)
+        rule = translation.TranslationRule(
+            props,
+            translation.TranslationRule.RESOLVE,
+            ['far'],
+            client_plugin=client_plugin,
+            finder='find_name_id')
+
+        rule.execute_rule(ignore_resolve_error=True)
+        self.assertEqual('one', props.get('far'))
+
     def test_resolve_rule_other(self):
         client_plugin, schema = self._test_resolve_rule()
         data = {'far': 'one'}
