@@ -53,6 +53,12 @@ HeatGroup = [
     cfg.StrOpt('project_domain_name',
                help="Project domain name, if keystone v3 auth_url"
                     "is used"),
+    cfg.StrOpt('user_domain_id',
+               help="User domain id, if keystone v3 auth_url"
+                    "is used"),
+    cfg.StrOpt('project_domain_id',
+               help="Project domain id, if keystone v3 auth_url"
+                    "is used"),
     cfg.StrOpt('region',
                help="The region name to use"),
     cfg.StrOpt('instance_type',
@@ -144,7 +150,7 @@ HeatGroup = [
                help='Count of retries to edit config file during sighup. If '
                     'another worker already edit config file, file can be '
                     'busy, so need to wait and try edit file again.'),
-    cfg.StrOpt('heat-config-notify-script',
+    cfg.StrOpt('heat_config_notify_script',
                default=('heat-config-notify'),
                help="Path to the script heat-config-notify"),
 
