@@ -50,15 +50,7 @@ iniset $conf_file heat_plugin minimal_instance_type m1.heat_micro
 openstack flavor create m1.heat_int --ram 512
 openstack flavor create m1.heat_micro --ram 128
 
-# Register the glance image for testing
-curl http://mirror.liquidtelecom.com/fedora/fedora/linux/releases/24/CloudImages/x86_64/images/Fedora-Cloud-Base-24-1.2.x86_64.qcow2 | openstack image create fedora-heat-test-image --disk-format qcow2 --container-format bare --public
-if [[ ${PIPESTATUS[0]} -ne 0 ]]; then
-   # The curl command failed, so the upload is mostly likely incorrect. Let's
-   # bail out early.
-   exit 1
-fi
-
-iniset $conf_file heat_plugin image_ref fedora-heat-test-image
+iniset $conf_file heat_plugin image_ref Fedora-Cloud-Base-27-1.6.x86_64
 iniset $conf_file heat_plugin boot_config_env $DEST/heat-templates/hot/software-config/boot-config/test_image_env.yaml
 iniset $conf_file heat_plugin heat_config_notify_script $DEST/heat-templates/hot/software-config/elements/heat-config/bin/heat-config-notify
 iniset $conf_file heat_plugin minimal_image_ref cirros-0.3.4-x86_64-uec
